@@ -1,13 +1,15 @@
-__all__ = ['dcmreaddata', 'datareader', 'datawriter', 'rawN', "datasets"]
-__version__ = "1.18.0"
+__all__ = ["dcmreaddata", "datareader", "datawriter", "rawN", "datasets"]
+__version__ = "2.5.1"
 # from pycut import Model, ImageGraphCut
 # from seed_editor_qt import QTSeedEditor
+from loguru import logger
 from .dcmreaddata import DicomReader
 from .dcmreaddata import dicomdir_info
 from .datawriter import DataWriter
 from .datareader import DataReader
 from .datareader import read
 from .datawriter import write
-from .datasets import download
-from .fsbrowser import remove_if_exists
-from imma import image_manipulation
+from .datasets import download, read_dataset, joinp
+from .files import remove_if_exists
+from imma import image_manipulation, dili
+logger.disable('io3d')
