@@ -12,36 +12,49 @@
 
 import logging
 
+# try:
+#     QString = unicode
+# except NameError:
+#     # Python 3
+#     QString = str
+
+QString = str
 logger = logging.getLogger(__name__)
 import argparse
 
-from PyQt4.QtGui import QGridLayout, QLabel,\
-    QPushButton, QLineEdit, QApplication
-from PyQt4 import QtGui
-from PyQt4.QtCore import Qt
+
+from PyQt5.QtWidgets import QGridLayout, QLabel, QPushButton, QLineEdit, QApplication, QDialog
+from PyQt5 import QtGui, QtWidgets
+from PyQt5.QtCore import Qt
+
+
 import sys
+
+
 import os.path
+
+
 import copy
 
 
 from . import datareader
+
+
 from . import cachefile as cachef
 
 
-class DataReaderWidget(QtGui.QWidget):
-
+class DataReaderWidget(QtWidgets.QWidget):
     def __init__(
-            self,
-            datapath=None,
-            loadfiledir='',
-            loaddir='',
-            show_message_function=None,
-            after_function=None,
-            before_function=None,
-            cachefile=None,
-            qt_app=None,
-
-    ) :
+        self,
+        datapath=None,
+        loadfiledir="",
+        loaddir="",
+        show_message_function=None,
+        after_function=None,
+        before_function=None,
+        cachefile=None,
+        qt_app=None,
+    ):
         """
 
         :param datapath: is also output var. Describes path to selected data
@@ -86,8 +99,8 @@ class DataReaderWidget(QtGui.QWidget):
         btn_load_file.clicked.connect(self.read_data_dir_dialog)
         self.mainLayout.addWidget(btn_load_file, 0, 1)
 
-        self.text_dcm_dir = QLabel('Data Path:')
-        self.text_dcm_data = QLabel('')  # data dimensions
+        self.text_dcm_dir = QLabel("Data Path:")
+        self.text_dcm_data = QLabel("")  # data dimensions
         self.text_dcm_data.setTextInteractionFlags(Qt.TextSelectableByMouse)
         self.mainLayout.addWidget(self.text_dcm_dir, 1, 0, 1, 2)
         self.mainLayout.addWidget(self.text_dcm_data, 2, 0, 1, 2)
@@ -98,23 +111,24 @@ class DataReaderWidget(QtGui.QWidget):
         """
 
         if self.cache is not None:
-            cache_loadfiledir = self.cache.get_or_none('loadfiledir')
+            cache_loadfiledir = self.cache.get_or_none("loadfiledir")
             self.loadfiledir = str(cache_loadfiledir)
 
         if self.loadfiledir is None:
-            self.loadfiledir = ''
+            self.loadfiledir = ""
         directory = str(self.loadfiledir)
-        from PyQt4.QtGui import QFileDialog
+        from PyQt5.QtWidgets import QFileDialog
+
         if not app:
             inner_app = QApplication(sys.argv)
         if self._skip_get_path_dialog_for_tests:
             dcmdir = self.datapath
         else:
             dcmdir = QFileDialog.getOpenFileName(
-                caption='Select Data File',
+                caption="Select Data File",
                 directory=directory
                 # ptions=QFileDialog.ShowDirsOnly,
-            )
+            )[0]
         # dcmdir = QFileDialog.getOpenFileName(
         #     caption='Select Data file',
         #     # ptions=QFileDialog.ShowDirsOnly,
@@ -124,20 +138,20 @@ class DataReaderWidget(QtGui.QWidget):
         if not app:
             inner_app.exit(0)
 
-        dcmdir = get_str(dcmdir)
+        dcmdir = get_str_py2_compatibility(dcmdir)
 
         if len(dcmdir) > 0:
-        #
-        #     dcmdir = "%s" % (dcmdir)
-        #     dcmdir = dcmdir.encode("utf8")
+            #
+            #     dcmdir = "%s" % (dcmdir)
+            #     dcmdir = dcmdir.encode("utf8")
             pass
         else:
             dcmdir = None
-
+            return dcmdir
 
         head, teil = os.path.split(dcmdir)
         if self.cache is not None:
-            self.cache.update('loadfiledir', head)
+            self.cache.update("loadfiledir", head)
         return dcmdir
 
     def __get_datadir(self, app=False):
@@ -148,35 +162,35 @@ class DataReaderWidget(QtGui.QWidget):
         # if :
         #     directory = self.oseg.input_datapath_start
         if self.cache is not None:
-            cache_loaddir = self.cache.get_or_none('loaddir')
+            cache_loaddir = self.cache.get_or_none("loaddir")
             self.loaddir = str(cache_loaddir)
             # self.loaddir = str(self.cache.get_or_none('loaddir'))
 
         if self.loaddir is None:
-            self.loaddir = ''
+            self.loaddir = ""
 
         directory = self.loaddir
 
-        from PyQt4.QtGui import QFileDialog
+        from PyQt5.QtWidgets import QFileDialog
+
         if not app:
             app_inner = QApplication(sys.argv)
         if self._skip_get_path_dialog_for_tests:
             dcmdir = self.datapath
         else:
             dcmdir = QFileDialog.getExistingDirectory(
-                caption='Select DICOM Folder',
+                caption="Select DICOM Folder",
                 options=QFileDialog.ShowDirsOnly,
-                directory=directory
+                directory=directory,
             )
             # pp.exec_()
         if not app:
             app_inner.exit(0)
 
-        dcmdir = get_str(dcmdir)
+        dcmdir = get_str_py2_compatibility(dcmdir)
 
         if len(dcmdir) > 0:
 
-
             # dcmdir = "%s" % (dcmdir)
             # dcmdir = dcmdir.encode("utf8")
             pass
@@ -184,24 +198,21 @@ class DataReaderWidget(QtGui.QWidget):
             dcmdir = None
 
         if self.cache is not None:
-            self.cache.update('loaddir', dcmdir)
+            self.cache.update("loaddir", dcmdir)
         return str(dcmdir)
 
     def read_data_file_dialog(self):
 
-
-        self.__show_message('Reading data file...')
+        self.__show_message("Reading data file...")
         QApplication.processEvents()
 
         if self.before_function is not None:
             self.before_function(self)
 
-        self.datapath = self.__get_datafile(
-            app=True,
-            )
+        self.datapath = self.__get_datafile(app=True)
 
         if self.datapath is None:
-            self.__show_message('No data path specified!')
+            self.__show_message("No data path specified!")
             return
         head, teil = os.path.split(self.datapath)
         self.loadfiledir = head
@@ -209,18 +220,16 @@ class DataReaderWidget(QtGui.QWidget):
         self.read_data_from_prepared_datapath()
 
     def read_data_dir_dialog(self):
-        self.__show_message('Reading data file...')
+        self.__show_message("Reading data file...")
         QApplication.processEvents()
 
         if self.before_function is not None:
             self.before_function(self)
 
-        self.datapath = self.__get_datadir(
-            app=True
-        )
+        self.datapath = self.__get_datadir(app=True)
 
         if self.datapath is None:
-            self.__show_message('No DICOM directory specified!')
+            self.__show_message("No DICOM directory specified!")
             return
         # head, teil = os.path.split(oseg.datapath)
         self.loaddir = copy.copy(self.datapath)
@@ -237,24 +246,34 @@ class DataReaderWidget(QtGui.QWidget):
 
         reader = datareader.DataReader()
 
-        self.datap = reader.Get3DData(self.datapath, dataplus_format=True, gui=True, qt_app=self.qt_app)
+        self.datap = reader.Get3DData(
+            self.datapath, dataplus_format=True, gui=True, qt_app=self.qt_app
+        )
 
-        _set_label_text(self.text_dcm_dir, _make_text_short(self.datapath), self.datapath)
-        _set_label_text(self.text_dcm_data, self.get_data_info())
+        _set_label_text(
+            self.text_dcm_dir, _make_text_short(self.datapath), self.datapath
+        )
+        _set_label_text(self.text_dcm_data, self.get_data_info(), replace_all=True)
         if self.after_function is not None:
             self.after_function(self)
-        self.__show_message('Data read finished')
+        self.__show_message("Data read finished")
 
     def get_data_info(self):
-        vx_size = self.datap['voxelsize_mm']
+        vx_size = self.datap["voxelsize_mm"]
         vsize = tuple([float(ii) for ii in vx_size])
-        ret = 'Data Dimensions: %dx%dx%d,  %fx%fx%f mm' % (self.datap['data3d'].shape + vsize)
+        ret = "Data Dimensions: %dx%dx%d,  %fx%fx%f mm" % (
+            self.datap["data3d"].shape + vsize
+        )
         if "StudyID" in self.datap and "StudyDate" in self.datap:
-            ret += "\nStudy ID: {}, Study Date, {}".format(self.datap["StudyID"], (self.datap["StudyDate"]))
+            ret += "\nStudy ID: {}, Study Date, {}".format(
+                self.datap["StudyID"], (self.datap["StudyDate"])
+            )
         if "PatientName" in self.datap:
             ret += "\nPatient Name: {}".format(self.datap["PatientName"])
         if "PatientAge" in self.datap and "PatientSex" in self.datap:
-            ret += "\nAge: {}, Sex {}".format(self.datap["PatientAge"], self.datap["PatientSex"])
+            ret += "\nAge: {}, Sex {}".format(
+                self.datap["PatientAge"], self.datap["PatientSex"]
+            )
         return ret
 
     def __show_message(self, msg):
@@ -265,12 +284,29 @@ class DataReaderWidget(QtGui.QWidget):
 
 
 def _make_text_short(text, max_lenght=40):
-    return text[:int(max_lenght/2)] + ".." + text[-int(max_lenght/2):]
+    return text[: int(max_lenght / 2)] + ".." + text[-int(max_lenght / 2) :]
 
 
-def _set_label_text(obj, text, tooltip=None):
+def _set_label_text(obj, text, tooltip=None, replace_all=False):
+    """
+    Keep text before first colon and replace the rest with new text.
+
+    If there is no colon in the
+    :param obj:
+    :param text:
+    :param tooltip:
+    :param replace_all: No colon is searched and whole text is replaced
+    :return:
+    """
     dlab = str(obj.text())
-    obj.setText(dlab[:dlab.find(':')] + ': %s' % text)
+    index_of_colon = dlab.find(": ")
+    if index_of_colon == -1:
+        index_of_colon = 0
+    else:
+        index_of_colon += 2
+    if replace_all:
+        index_of_colon = 0
+    obj.setText(dlab[:index_of_colon] + "%s" % text)
     if tooltip is not None:
         obj.setToolTip(tooltip)
 
@@ -284,14 +320,17 @@ def my_after_fcn(arg):
     print(arg.loaddir)
     print(arg.loadfiledir)
 
-def get_str(text):
+
+def get_str_py2_compatibility(text):
     if sys.version_info.major == 2:
-        import PyQt4.QtCore
-        if type(text) is PyQt4.QtCore.QString:
+        import PyQt5.QtCore
+
+        if type(text) is QString:
             text = str(text)
 
     return text
 
+
 def main():
     logger = logging.getLogger()
 
@@ -309,9 +348,7 @@ def main():
     # logger.debug('start')
 
     # input parser
-    parser = argparse.ArgumentParser(
-        description=__doc__
-    )
+    parser = argparse.ArgumentParser(description=__doc__)
     # parser.add_argument(
     #     '-i', '--inputfile',
     #     default=None,
@@ -319,48 +356,52 @@ def main():
     #     help='input file'
     # )
     parser.add_argument(
-        '-ld', '--loaddir',
+        "-ld",
+        "--loaddir",
         default="",
         # required=True,
-        help='init dir for dir dialog'
+        help="init dir for dir dialog",
     )
     parser.add_argument(
-        '-lf', '--loadfiledir',
+        "-lf",
+        "--loadfiledir",
         default="",
         # required=True,
-        help='init dir for file dialog'
+        help="init dir for file dialog",
     )
+    parser.add_argument("-d", "--debug", action="store_true", help="Debug mode")
     parser.add_argument(
-        '-d', '--debug', action='store_true',
-        help='Debug mode')
-    parser.add_argument(
-        '-cf', '--cachefile',
+        "-cf",
+        "--cachefile",
         default=None,
         # required=True,
-        help='cache file for last load dir path info'
+        help="cache file for last load dir path info",
     )
     args = parser.parse_args()
 
     if args.debug:
         ch.setLevel(logging.DEBUG)
 
-    app = QtGui.QApplication(sys.argv)
+    app = QtWidgets.QApplication(sys.argv)
 
     # w = QtGui.QWidget()
     # w = DictEdit(dictionary={'jatra':2, 'ledviny':7})
     w = DataReaderWidget(
-        loaddir=args.loaddir, loadfiledir=args.loadfiledir,
+        loaddir=args.loaddir,
+        loadfiledir=args.loadfiledir,
         cachefile=args.cachefile,
-        after_function=my_after_fcn, before_function=my_before_fcn,
-        qt_app=app
+        after_function=my_after_fcn,
+        before_function=my_before_fcn,
+        qt_app=app,
     )
     w.resize(250, 150)
     w.move(300, 300)
-    w.setWindowTitle('io3dQtWidget')
+    w.setWindowTitle("io3dQtWidget")
     w.show()
 
     sys.exit(app.exec_())
 
+
 # def something_to_str(path):
 #     outpath = None
 #     if type(path) is str:
