@@ -9,8 +9,7 @@ Example:
 $ dcmreaddata -d sample_data -o head.mat
 """
 
-import logging
-logger = logging.getLogger(__name__)
+from loguru import logger
 import os
 import re
 import sys
@@ -21,6 +20,7 @@ try:
     import pydicom
 except ImportError:
     import warnings
+
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
         import dicom as pydicom
@@ -127,16 +127,24 @@ class DicomReader:
 
     """
 
-    def __init__(self, dirpath=None, initdir='.',
-                 qt_app=None, gui=True, series_number=None,
-                 get_series_number_callback=None,
-                 force_create_dicomdir=False,
-                 force_read=False
-                 ):
+    def __init__(
+        self,
+        dirpath=None,
+        initdir=".",
+        qt_app=None,
+        gui=True,
+        series_number=None,
+        get_series_number_callback=None,
+        force_create_dicomdir=False,
+        force_read=False,
+    ):
         self.valid = False
         self.dirpath = os.path.expanduser(dirpath)
-        self.dicomdirectory = DicomDirectory(self.dirpath, force_create_dicomdir=force_create_dicomdir,
-                                             force_read=force_read)
+        self.dicomdirectory = DicomDirectory(
+            self.dirpath,
+            force_create_dicomdir=force_create_dicomdir,
+            force_read=force_read,
+        )
         self.force_read = force_read
         # self.dicomdir_info = self.dicomdirectory.get_dicomdir_info()
         self.series_number = series_number
@@ -161,10 +169,15 @@ class DicomReader:
 
     def set_series_number(self, series_number):
         self.files_in_serie, self.files_in_serie_with_info = self.dicomdirectory.get_sorted_series_files(
-            series_number=series_number, return_files_with_info=True)
+            series_number=series_number, return_files_with_info=True
+        )
         if len(self.files_in_serie) == 0:
             # logger.exception("No data for series number {} in directory {}".format(series_number, dirpath))
-            raise ValueError("No data for series number {} in directory {}".format(self.series_number, self.dirpath))
+            raise ValueError(
+                "No data for series number {} in directory {}".format(
+                    self.series_number, self.dirpath
+                )
+            )
 
     def __check_series_number(self):
         if self.series_number is not None:
@@ -177,10 +190,7 @@ class DicomReader:
             if len(bins) > 1:
                 if self.series_number is None:  # pragma: no cover
                     self.series_number = self.get_series_number_callback(
-                        self,
-                        counts,
-                        bins,
-                        qt_app=self.qt_app
+                        self, counts, bins, qt_app=self.qt_app
                     )
 
             else:
@@ -221,8 +231,9 @@ class DicomReader:
                         data2d = decode_overlay_slice(data, i_overlay)
                         # mport pdb; pdb.set_trace()
                         shp2 = data2d.shape
-                        overlay[i_overlay] = np.zeros([len(dcmlist), shp2[0],
-                                                       shp2[1]], dtype=np.int8)
+                        overlay[i_overlay] = np.zeros(
+                            [len(dcmlist), shp2[0], shp2[1]], dtype=np.int8
+                        )
                         overlay[i_overlay][-i - 1, :, :] = data2d
 
                     except Exception:
@@ -237,8 +248,7 @@ class DicomReader:
                         data2d = decode_overlay_slice(data, i_overlay)
                         overlay[i_overlay][-i - 1, :, :] = data2d
                     except Exception:
-                        logger.warning('Problem with overlay number ' +
-                                       str(i_overlay))
+                        logger.warning("Problem with overlay number " + str(i_overlay))
 
         return overlay
 
@@ -267,7 +277,9 @@ class DicomReader:
             data2d1 = data.pixel_array
             data = self._read_file(dcmlist[1])
             data2d2 = data.pixel_array
-            if (data2d1.shape[0] == data2d2.shape[0]) and (data2d1.shape[1] == data2d2.shape[1]):
+            if (data2d1.shape[0] == data2d2.shape[0]) and (
+                data2d1.shape[1] == data2d2.shape[1]
+            ):
                 pass
             else:
                 dcmlist.pop(0)
@@ -285,31 +297,46 @@ class DicomReader:
 
             if len(data3d) == 0:
                 shp2 = new_data2d.shape
-                data3d = np.zeros([len(dcmlist), shp2[0], shp2[1]],
-                                  dtype=new_data2d.dtype)
+                data3d = np.zeros(
+                    [len(dcmlist), shp2[0], shp2[1]], dtype=new_data2d.dtype
+                )
                 slope, inter = dcmtools.get_slope_and_intercept_from_pdcm(data)
 
-
-
             # first readed slide is at the end
 
-            if (data3d.shape[1] == new_data2d.shape[0]) and (data3d.shape[2] == new_data2d.shape[1]):
+            if (data3d.shape[1] == new_data2d.shape[0]) and (
+                data3d.shape[2] == new_data2d.shape[1]
+            ):
                 data3d[-i - 1, :, :] = new_data2d
             else:
-                msg = "Problem with shape " + \
-                      "Data size: " + str(data3d.nbytes) + \
-                      ', shape: ' + str(shp2) + 'x' + str(len(dcmlist)) + \
-                      ' file ' + onefile
+                msg = (
+                    "Problem with shape "
+                    + "Data size: "
+                    + str(data3d.nbytes)
+                    + ", shape: "
+                    + str(shp2)
+                    + "x"
+                    + str(len(dcmlist))
+                    + " file "
+                    + onefile
+                )
                 logger.warning(msg)
                 print(msg)
 
-            logger.debug("Data size: " + str(data3d.nbytes)
-                         + ', shape: ' + str(shp2) + 'x' + str(len(dcmlist))
-                         + ' file ' + onefile)
+            logger.debug(
+                "Data size: "
+                + str(data3d.nbytes)
+                + ", shape: "
+                + str(shp2)
+                + "x"
+                + str(len(dcmlist))
+                + " file "
+                + onefile
+            )
         data3d = misc.use_economic_dtype(data3d, slope=slope, inter=inter)
         # if original_dtype == np.uint16 and data3d.dtype == np.int16:
         #     data3d = data3d.astype(np.int32)
-            # or just force set slope=0.5, inter = 0
+        # or just force set slope=0.5, inter = 0
         # new_data2d = rescale_pixel_array(data2d, slope, inter)
         # if printRescaleWarning:
         #     print("Automatic Rescale with slope 0.5")
@@ -321,36 +348,31 @@ class DicomReader:
     def get_metaData(self):
         dcmlist = self.files_in_serie
         # self.dicomdirectory.get_metadata_new(series_number=self.series_number)
-        return self.dicomdirectory.get_metaData(dcmlist=dcmlist, series_number=self.series_number)
+        return self.dicomdirectory.get_metaData(
+            dcmlist=dcmlist, series_number=self.series_number
+        )
 
     def dcmdirstats(self):
         return self.dicomdirectory.get_stats_of_series_in_dir()
 
 
 def get_one_serie_info(series_info, serie_number):
-    strl = str(serie_number) + " (" \
-           + str(series_info[serie_number]['Count'])
+    strl = str(serie_number) + " (" + str(series_info[serie_number]["Count"])
     try:
-        strl = strl + ", " \
-               + str(series_info[serie_number]['Modality'])
-        strl = strl + ", " \
-               + str(series_info[serie_number]['SeriesDescription'])
-        strl = strl + ", " \
-               + str(series_info[serie_number]['ImageComments'])
+        strl = strl + ", " + str(series_info[serie_number]["Modality"])
+        strl = strl + ", " + str(series_info[serie_number]["SeriesDescription"])
+        strl = strl + ", " + str(series_info[serie_number]["ImageComments"])
     except Exception:
         logger.debug(
-            'Tag Modality, SeriesDescription or ImageComment not found in dcminfo'
+            "Tag Modality, SeriesDescription or ImageComment not found in dcminfo"
         )
         pass
     try:
-        strl = strl + ", " \
-               + str(series_info[serie_number]['StudyDate'])
+        strl = strl + ", " + str(series_info[serie_number]["StudyDate"])
     except Exception:
-        logger.debug(
-            'Tag StudyDate not found in dcminfo'
-        )
+        logger.debug("Tag StudyDate not found in dcminfo")
         pass
-    strl = strl + ')'
+    strl = strl + ")"
     return strl
 
 
@@ -378,37 +400,36 @@ def files_in_dir(dirpath, wildcard="*", startpath=None):
         completedirpath = dirpath
 
     if os.path.exists(completedirpath):
-        logger.info('completedirpath = ' + completedirpath)
+        logger.info("completedirpath = " + completedirpath)
 
     else:
-        logger.error('Wrong path: ' + completedirpath)
-        raise Exception('Wrong path : ' + completedirpath)
+        logger.error("Wrong path: " + completedirpath)
+        raise Exception("Wrong path : " + completedirpath)
 
     for infile in glob.glob(os.path.join(completedirpath, wildcard)):
         filelist.append(infile)
 
     if len(filelist) == 0:
-        logger.error('No required files in path: ' + completedirpath)
-        raise Exception('No required file in path: ' + completedirpath)
+        logger.error("No required files in path: " + completedirpath)
+        raise Exception("No required file in path: " + completedirpath)
 
     return filelist
 
 
 def _prepare_metadata_line(dcmdata, teil):
-    metadataline = {'filename': teil,
-                    'SeriesNumber': get_series_number(
-                        dcmdata),
-                    'SliceLocation': get_slice_location(
-                        dcmdata, teil)
-                    }
+    metadataline = {
+        "filename": teil,
+        "SeriesNumber": get_series_number(dcmdata),
+        "SliceLocation": get_slice_location(dcmdata, teil),
+    }
     metadataline = attr_to_dict(dcmdata, "AcquisitionTime", metadataline)
     return metadataline
 
 
 class DicomDirectory:
     def __init__(self, dirpath, force_create_dicomdir=False, force_read=False):
-        self.dicomdir_filename = 'dicomdir.pkl'
-        self.standard_dicomdir_filename = 'DICOMDIR'
+        self.dicomdir_filename = "dicomdir.pkl"
+        self.standard_dicomdir_filename = "DICOMDIR"
         self.files_with_info = None
         self.dcmdirplus = None
         self.dirpath = dirpath
@@ -463,7 +484,9 @@ class DicomDirectory:
         # TODO implement simplier metadata function
         # automatic test is prepared
 
-        files, files_with_info = self.get_sorted_series_files(series_number=series_number, return_files_with_info=True)
+        files, files_with_info = self.get_sorted_series_files(
+            series_number=series_number, return_files_with_info=True
+        )
         metadata = {
             # 'voxelsize_mm': voxelsize_mm,
             # 'Modality': data1.Modality,
@@ -510,12 +533,12 @@ class DicomDirectory:
             voxeldepth = self._get_slice_location_difference(dcmlist, ifile)
             voxeldepth_end = self._get_slice_location_difference(dcmlist, -2)
             if voxeldepth != voxeldepth_end:
-                logger.warning("Depth of slices is not the same in beginning and end of the sequence")
+                logger.warning(
+                    "Depth of slices is not the same in beginning and end of the sequence"
+                )
                 voxeldepth_1 = self._get_slice_location_difference(dcmlist, 1)
                 voxeldepth = np.median([voxeldepth, voxeldepth_end, voxeldepth_1])
 
-
-
             # head1, teil1 = os.path.split(dcmlist[ifile])
             # head2, teil2 = os.path.split(dcmlist[ifile + 1])
             #
@@ -524,51 +547,48 @@ class DicomDirectory:
             # loc2 = get_slice_location(data2, teil2)
             # voxeldepth = float(np.abs(loc1 - loc2))
         except Exception:
-            logger.warning('Problem with voxel depth. Using SliceThickness')
+            logger.warning("Problem with voxel depth. Using SliceThickness")
             logger.debug(traceback.format_exc())
             # + ' SeriesNumber: ' + str(data1.SeriesNumber))
 
             try:
                 voxeldepth = float(data1.SliceThickness)
             except Exception:
-                logger.warning('Probem with SliceThicknes, setting zero. '
-                               + traceback.format_exc())
+                logger.warning(
+                    "Probem with SliceThicknes, setting zero. " + traceback.format_exc()
+                )
                 voxeldepth = 0
 
         try:
             pixelsize_mm = data1.PixelSpacing
         except:
-            logger.warning('Problem with PixelSpacing. Using [1,1]')
+            logger.warning("Problem with PixelSpacing. Using [1,1]")
             pixelsize_mm = [1, 1]
-        voxelsize_mm = [
-            voxeldepth,
-            float(pixelsize_mm[0]),
-            float(pixelsize_mm[1]),
-        ]
-        metadata = {'voxelsize_mm': voxelsize_mm,
-                    'Modality': data1.Modality,
-                    'SeriesNumber': series_number
-                    }
+        voxelsize_mm = [voxeldepth, float(pixelsize_mm[0]), float(pixelsize_mm[1])]
+        metadata = {
+            "voxelsize_mm": voxelsize_mm,
+            "Modality": data1.Modality,
+            "SeriesNumber": series_number,
+        }
 
         try:
-            metadata['SeriesDescription'] = data1.SeriesDescription
+            metadata["SeriesDescription"] = data1.SeriesDescription
 
         except:
             logger.info(
-                'Problem with tag SeriesDescription, SeriesNumber: ' +
-                str(data1.SeriesNumber))
+                "Problem with tag SeriesDescription, SeriesNumber: "
+                + str(data1.SeriesNumber)
+            )
         try:
-            metadata['ImageComments'] = data1.ImageComments
+            metadata["ImageComments"] = data1.ImageComments
         except:
-            logger.info(
-                'Problem with tag ImageComments')
+            logger.info("Problem with tag ImageComments")
             # , SeriesNumber: ' +
             # str(data1.SeriesNumber))
         try:
-            metadata['Modality'] = data1.Modality
+            metadata["Modality"] = data1.Modality
         except:
-            logger.info(
-                'Problem with tag Modality')
+            logger.info("Problem with tag Modality")
             # SeriesNumber: ' +
             #     str(data1.SeriesNumber))
         metadata = attr_to_dict(data1, "AcquisitionDate", metadata)
@@ -582,21 +602,17 @@ class DicomDirectory:
         metadata = attr_to_dict(data1, "PatientName", metadata)
         # metadata = attr_to_dict(data1, "AcquisitionTime", metadata)
 
-        metadata['dcmfilelist'] = dcmlist
+        metadata["dcmfilelist"] = dcmlist
         return metadata
 
     def get_stats_of_studies_and_series_in_dir(self):
-        retval = {
-            1: {
-                "info": None,
-                "series": self.get_stats_of_series_in_dir()
-            }
-        }
+        retval = {1: {"info": None, "series": self.get_stats_of_series_in_dir()}}
         return retval
 
     def get_stats_of_series_in_dir_as_dataframe(self, study_id=None):
         series_stats = self.get_stats_of_series_in_dir(study_id)
         import pandas as pd
+
         study_df = pd.DataFrame(series_stats).transpose()
         return study_df
 
@@ -608,19 +624,20 @@ class DicomDirectory:
             logger.error("study_id tag is not implemented yet")
             return
         import numpy as np
+
         dcmdir = self.files_with_info
         # get series number
         # vytvoření slovníku, kde je klíčem číslo série a hodnotou jsou všechny
         # informace z dicomdir
-        series_info = {line['SeriesNumber']: line for line in dcmdir}
+        series_info = {line["SeriesNumber"]: line for line in dcmdir}
 
         # počítání velikosti série
         try:
-            dcmdirseries = [line['SeriesNumber'] for line in dcmdir]
+            dcmdirseries = [line["SeriesNumber"] for line in dcmdir]
 
         except:
-            logger.debug('Dicom tag SeriesNumber not found')
-            series_info = {0: {'Count': 0}}
+            logger.debug("Dicom tag SeriesNumber not found")
+            series_info = {0: {"Count": 0}}
             return series_info
             # eturn [0],[0]
 
@@ -629,15 +646,14 @@ class DicomDirectory:
         # sestavení informace o velikosti série a slovníku
 
         for i in range(0, len(bins)):
-            series_info[bins[i]]['Count'] = counts[i]
+            series_info[bins[i]]["Count"] = counts[i]
 
             # adding information from files
             lst = self.get_sorted_series_files(series_number=bins[i])
             metadata = self.get_metaData(dcmlist=lst, series_number=bins[i])
             # adding dictionary metadata to series_info dictionary
             series_info[bins[i]] = dict(
-                list(series_info[bins[i]].items()) +
-                list(metadata.items())
+                list(series_info[bins[i]].items()) + list(metadata.items())
             )
 
         return series_info
@@ -646,11 +662,11 @@ class DicomDirectory:
         """
         Print series_info from dcmdirstats
         """
-        strinfo = ''
+        strinfo = ""
         if len(series_info) > minimal_series_number:
             for serie_number in series_info.keys():
                 strl = get_one_serie_info(series_info, serie_number)
-                strinfo = strinfo + strl + '\n'
+                strinfo = strinfo + strl + "\n"
                 # rint strl
 
         return strinfo
@@ -659,9 +675,7 @@ class DicomDirectory:
         if series_info is None:
             series_info = self.get_stats_of_series_in_dir()
 
-        study_info = {
-
-        }
+        study_info = {}
         key = list(series_info)[0]
         if "StudyDate" in series_info[key]:
             study_info["StudyDate"] = series_info[key]["StudyDate"]
@@ -687,32 +701,32 @@ class DicomDirectory:
         createdcmdir = True
 
         dicomdirfile = os.path.join(self.dirpath, self.dicomdir_filename)
-        ftype = 'pickle'
+        ftype = "pickle"
         # if exist dicomdir file and is in correct version, use it
         if os.path.exists(dicomdirfile):
             try:
                 dcmdirplus = misc.obj_from_file(dicomdirfile, ftype)
-                if dcmdirplus['version'] == __version__:
+                if dcmdirplus["version"] == __version__:
                     createdcmdir = False
-                dcmdir = dcmdirplus['filesinfo']
+                dcmdir = dcmdirplus["filesinfo"]
             except Exception:
-                logger.debug('Found dicomdir.pkl with wrong version')
+                logger.debug("Found dicomdir.pkl with wrong version")
                 createdcmdir = True
 
         if createdcmdir or self.force_create_dicomdir:
             dcmdirplus = self._create_dicomdir_info()
-            dcmdir = dcmdirplus['filesinfo']
+            dcmdir = dcmdirplus["filesinfo"]
             if (writedicomdirfile) and len(dcmdir) > 0:
                 # obj_to_file(dcmdirplus, dicomdirfile, ftype)
                 try:
                     misc.obj_to_file(dcmdirplus, dicomdirfile, ftype)
                 except:
-                    logger.warning('Cannot write dcmdir file')
+                    logger.warning("Cannot write dcmdir file")
                     traceback.print_exc()
 
                 # bj_to_file(dcmdir, dcmdiryamlpath )
 
-        dcmdir = dcmdirplus['filesinfo']
+        dcmdir = dcmdirplus["filesinfo"]
         self.dcmdirplus = dcmdirplus
         self.files_with_info = dcmdir
         return dcmdir
@@ -725,7 +739,7 @@ class DicomDirectory:
         # dcmdirseries = []
         for line in self.files_with_info:
             if "SeriesNumber" in line:
-                sn = line['SeriesNumber']
+                sn = line["SeriesNumber"]
             else:
                 sn = None
             if sn in countsd:
@@ -736,7 +750,6 @@ class DicomDirectory:
         bins = list(countsd)
         counts = list(countsd.values())
 
-
         # try:
         #     dcmdirseries = [line['SeriesNumber'] for line in self.files_with_info]
         # except:
@@ -764,8 +777,15 @@ class DicomDirectory:
         # return counts.tolist(), bins.tolist()
         return counts, bins
 
-    def get_sorted_series_files(self, startpath="", series_number=None, return_files_with_info=False,
-                                sort_keys="SliceLocation", return_files=True, remove_doubled_slice_locations=True):
+    def get_sorted_series_files(
+        self,
+        startpath="",
+        series_number=None,
+        return_files_with_info=False,
+        sort_keys="SliceLocation",
+        return_files=True,
+        remove_doubled_slice_locations=True,
+    ):
         """
         Function returns sorted list of dicom files. File paths are organized
         by SeriesUID, StudyUID and FrameUID
@@ -782,23 +802,19 @@ class DicomDirectory:
 
         # select sublist with SeriesNumber
         if series_number is not None:
-            dcmdir = [
-                line for line in dcmdir if line['SeriesNumber'] == series_number
-            ]
+            dcmdir = [line for line in dcmdir if line["SeriesNumber"] == series_number]
         dcmdir = sort_list_of_dicts(dcmdir, keys=sort_keys)
 
-        logger.debug('SeriesNumber: ' + str(series_number))
+        logger.debug("SeriesNumber: " + str(series_number))
 
         if remove_doubled_slice_locations:
             dcmdir = self._remove_doubled_slice_locations(dcmdir)
 
         filelist = []
         for onefile in dcmdir:
-            filelist.append(os.path.join(startpath,
-                                         self.dirpath, onefile['filename']))
+            filelist.append(os.path.join(startpath, self.dirpath, onefile["filename"]))
             # head, tail = os.path.split(onefile['filename'])
 
-
         retval = []
         if return_files:
             retval.append(filelist)
@@ -819,7 +835,7 @@ class DicomDirectory:
         prev_slice_location = None
         for item in dcmdir:
             actual_slice_location = item["SliceLocation"]
-            if  actual_slice_location != prev_slice_location:
+            if actual_slice_location != prev_slice_location:
                 new_dcmdir.append(item)
             prev_slice_location = actual_slice_location
 
@@ -838,7 +854,9 @@ class DicomDirectory:
             head, teil = os.path.split(filepath)
             dcmdata = None
             if os.path.isdir(filepath):
-                logger.debug("Subdirectory found in series dir is ignored: " + str(filepath))
+                logger.debug(
+                    "Subdirectory found in series dir is ignored: " + str(filepath)
+                )
                 continue
             try:
                 dcmdata = pydicom.read_file(filepath)
@@ -852,8 +870,9 @@ class DicomDirectory:
                 except Exception as e:
                     if teil != self.dicomdir_filename:
                         # print('Dicom read problem with file ' + filepath)
-                        logger.info('Dicom read problem with file ' + filepath)
+                        logger.info("Dicom read problem with file " + filepath)
                         import traceback
+
                         logger.debug(traceback.format_exc())
             if hasattr(dcmdata, "DirectoryRecordSequence"):
                 # file is DICOMDIR - metainfo about files in directory
@@ -866,9 +885,9 @@ class DicomDirectory:
 
         # if SliceLocation is None, it is sorted to the end
         # this is not necessary it can be deleted
-        files.sort(key=lambda x: (x['SliceLocation'] is None, x["SliceLocation"]))
+        files.sort(key=lambda x: (x["SliceLocation"] is None, x["SliceLocation"]))
 
-        dcmdirplus = {'version': __version__, 'filesinfo': files, }
+        dcmdirplus = {"version": __version__, "filesinfo": files}
         if "StudyDate" in metadataline:
             dcmdirplus["StudyDate"] = metadataline["StudyDate"]
         return dcmdirplus
@@ -882,7 +901,7 @@ def get_slice_location(dcmdata, teil=None):
     :return:
     """
     slice_location = None
-    if hasattr(dcmdata, 'SliceLocation'):
+    if hasattr(dcmdata, "SliceLocation"):
         # print(dcmdata.SliceLocation)
         # print(type(dcmdata.SliceLocation))
         try:
@@ -890,13 +909,15 @@ def get_slice_location(dcmdata, teil=None):
         except Exception as exc:
             logger.info("It is not possible to use SliceLocation")
             logger.debug(traceback.format_exc())
-    if slice_location is None and hasattr(dcmdata, "SliceThickness") and teil is not None:
-        logger.debug(
-            "Estimating SliceLocation wiht image number and SliceThickness"
-        )
+    if (
+        slice_location is None
+        and hasattr(dcmdata, "SliceThickness")
+        and teil is not None
+    ):
+        logger.debug("Estimating SliceLocation wiht image number and SliceThickness")
 
         # from builtins import map
-        i = list(map(int, re.findall('\d+', teil)))
+        i = list(map(int, re.findall(r"\d+", teil)))
         i = i[-1]
         try:
             slice_location = float(i * float(dcmdata.SliceThickness))
@@ -906,8 +927,11 @@ def get_slice_location(dcmdata, teil=None):
             logger.debug(traceback.format_exc())
             logger.debug("SliceThickness problem")
 
-    if slice_location is None and hasattr(dcmdata, "ImagePositionPatient") and hasattr(dcmdata,
-                                                                                       "ImageOrientationPatient"):
+    if (
+        slice_location is None
+        and hasattr(dcmdata, "ImagePositionPatient")
+        and hasattr(dcmdata, "ImageOrientationPatient")
+    ):
         if dcmdata.ImageOrientationPatient == [1, 0, 0, 0, 1, 0]:
             slice_location = dcmdata.ImagePositionPatient[2]
         else:
@@ -920,7 +944,7 @@ def get_slice_location(dcmdata, teil=None):
 
 def get_series_number(dcmdata):
     series_number = 0
-    if hasattr(dcmdata, 'SeriesNumber') and dcmdata.SeriesNumber != '':
+    if hasattr(dcmdata, "SeriesNumber") and dcmdata.SeriesNumber != "":
         series_number = dcmdata.SeriesNumber
         return series_number
 
@@ -937,6 +961,7 @@ def attr_to_dict(obj, attr, dct):
         dct[attr] = getattr(obj, attr)
     return dct
 
+
 def get_series_number_by_guess_for_liver(dcmreader, counts, bins, qt_app=None):
     """
     Select the venous series from CT with around 200 images
@@ -949,30 +974,65 @@ def get_series_number_by_guess_for_liver(dcmreader, counts, bins, qt_app=None):
     series_info = dcmreader.dicomdirectory.get_stats_of_series_in_dir()
     print(dcmreader.print_series_info(series_info))
     import pandas as pd
+
     df = pd.DataFrame(list(series_info.values()))
 
-    #select CT
-    df = df[df["Modality"].str.lower().str.contains("ct") == True]
-    # select just venous
-    df = df[df["SeriesDescription"].str.lower().str.contains("ven") == True]
-    # remove saggittal
-    df = df[df["SeriesDescription"].str.lower().str.contains("sag") == False]
-    # remove cor
-    df = df[df["SeriesDescription"].str.lower().str.contains("cor") == False]
+    # select CT
+    df["SeriesSelectionScore"] = 0
+    df.loc[
+        df["Modality"].str.lower().str.contains("ct") == True, "SeriesSelectionScore"
+    ] += 1000
+    # print(df["Modality"].str.lower())
+    # print(df["Modality"].str.lower().str.contains("ct"))
+    selection = df["Modality"].str.lower().str.contains("ct")
+    # print(df[["SeriesNumber", "Modality", "SeriesSelectionScore", "SeriesDescription"]])
+    # # select just venous
+    df.loc[
+        df["SeriesDescription"].str.lower().str.contains("ven") == True,
+        "SeriesSelectionScore",
+    ] += 100
+    df.loc[
+        df["SeriesDescription"].str.lower().str.contains("sag") == True,
+        "SeriesSelectionScore",
+    ] -= 100
+    df.loc[
+        df["SeriesDescription"].str.lower().str.contains("cor") == True,
+        "SeriesSelectionScore",
+    ] -= 100
+
+    df.loc[
+        df["SeriesDescription"].str.lower().str.contains("body") == True,
+        "SeriesSelectionScore",
+    ] += 30
+    df.loc[
+        df["SeriesDescription"].str.lower().str.contains("lung") == True,
+        "SeriesSelectionScore",
+    ] -= 10
+    # print(df[["SeriesNumber", "Modality", "SeriesSelectionScore", "SeriesDescription"]])
     df["dst_to_200"] = np.abs(200 - df.Count)
-    dfs = df.sort_values(by="dst_to_200", ascending=True)
+    df["SeriesSelectionScore"] -= df["dst_to_200"]
+    dfs = df.sort_values(by="SeriesSelectionScore", ascending=False)
+    # print(dfs[["SeriesNumber", "Modality", "SeriesSelectionScore", "SeriesDescription", "Count"]])
+    # df = df[df["Modality"].str.lower().str.contains("ct") == True]
+    # # select just venous
+    # df = df[df["SeriesDescription"].str.lower().str.contains("ven") == True]
+    # # remove saggittal
+    # df = df[df["SeriesDescription"].str.lower().str.contains("sag") == False]
+    # # remove cor
+    # df = df[df["SeriesDescription"].str.lower().str.contains("cor") == False]
+    # df["dst_to_200"] = np.abs(200 - df.Count)
+    # dfs = df.sort_values(by="dst_to_200", ascending=True)
     sn = list(dfs.SeriesNumber)[0]
 
     return sn
 
 
-
 def get_series_number_console(dcmreader, counts, bins, qt_app=None):  # pragma: no cover
 
-    print('series')
+    print("series")
     series_info = dcmreader.dicomdirectory.get_stats_of_series_in_dir()
     print(dcmreader.print_series_info(series_info))
-    snstring = raw_input('Select Serie: ')
+    snstring = raw_input("Select Serie: ")
 
     sn = int(snstring)
     return sn
@@ -989,9 +1049,12 @@ def get_series_number_qt(dcmreader, counts, bins, qt_app=None):  # pragma: no co
         print(qt_app)
 
     series_info = dcmreader.dicomdirectory.get_stats_of_series_in_dir()
-    study_info_msg = dcmreader.dicomdirectory.get_study_info_msg(series_info=series_info)
+    study_info_msg = dcmreader.dicomdirectory.get_study_info_msg(
+        series_info=series_info
+    )
     print(dcmreader.print_series_info(series_info))
-    from PyQt4.QtGui import QInputDialog
+    from PyQt5.QtWidgets import QInputDialog
+
     # bins = ', '.join([str(ii) for ii in bins])
     sbins = [str(ii) for ii in bins]
     sbinsd = {}
@@ -1000,31 +1063,32 @@ def get_series_number_qt(dcmreader, counts, bins, qt_app=None):  # pragma: no co
         sbinsd[strl] = serie_number
         # sbins.append(str(ii) + "  " + serie_number)
     sbins = list(sbinsd)
-    snstring, ok = \
-        QInputDialog.getItem(qt_app,
-                             'Serie Selection',
-                             study_info_msg +
-                             ' Select serie:',
-                             sbins,
-                             editable=False)
+    snstring, ok = QInputDialog.getItem(
+        qt_app,
+        "Serie Selection",
+        study_info_msg + " Select serie:",
+        sbins,
+        editable=False,
+    )
     sn = sbinsd[str(snstring)]
     return sn
 
 
-def get_dcmdir_qt(app=False, directory=''):  # pragma: no cover
-    from PyQt4.QtGui import QFileDialog, QApplication
+def get_dcmdir_qt(app=False, directory=""):  # pragma: no cover
+    from PyQt5.QtGui import QFileDialog, QApplication
+
     if app:
         dcmdir = QFileDialog.getExistingDirectory(
-            caption='Select DICOM Folder',
+            caption="Select DICOM Folder",
             options=QFileDialog.ShowDirsOnly,
-            directory=directory
+            directory=directory,
         )
     else:
         app = QApplication(sys.argv)
         dcmdir = QFileDialog.getExistingDirectory(
-            caption='Select DICOM Folder',
+            caption="Select DICOM Folder",
             options=QFileDialog.ShowDirsOnly,
-            directory=directory
+            directory=directory,
         )
         # pp.exec_()
         app.exit(0)
@@ -1057,53 +1121,71 @@ def sort_list_of_dicts(lst_of_dct, keys, reverse=False, **sort_args):
     dcmdir = lst_of_dct
     # sorting is based on two values in tuple (has_this_key: bool, value_or_None)
     # dcmdir.sort(key=lambda x: [((False, x[key] if x[key] is not None else 0) if key in x else (True, 0)) for key in keys], reverse=reverse, **sort_args)
-    dcmdir.sort(key=lambda x: [((False, x[key] if x[key] is not None else 0) if key in x else (True, 0)) for key in keys], reverse=reverse, **sort_args)
+    dcmdir.sort(
+        key=lambda x: [
+            ((False, x[key] if x[key] is not None else 0) if key in x else (True, 0))
+            for key in keys
+        ],
+        reverse=reverse,
+        **sort_args
+    )
     # dcmdir.sort(key=lambda x: [(x[key] for key in keys], reverse=reverse, **sort_args)
     return dcmdir
 
     # dcmdir.sort(key=lambda x: x[sort_key])
 
 
-usage = '%prog [options]\n' + __doc__.rstrip()
+usage = "%prog [options]\n" + __doc__.rstrip()
 help = {
-    'dcm_dir': 'DICOM data direcotory',
-    'out_file': 'store the output matrix to the file',
+    "dcm_dir": "DICOM data direcotory",
+    "out_file": "store the output matrix to the file",
     "degrad": "degradation of input data. For no degradation use 1",
-    'debug': 'Print debug info',
-    'zoom': 'Resize input data wit defined zoom. Use zoom 0.5 to obtain half\
-voxels. Various zoom can be used for each axis: -z [1,0.5,2.5]'
+    "debug": "Print debug info",
+    "zoom": "Resize input data wit defined zoom. Use zoom 0.5 to obtain half\
+voxels. Various zoom can be used for each axis: -z [1,0.5,2.5]",
 }
 
 if __name__ == "__main__":  # pragma: no cover
-    parser = OptionParser(description='Read DIOCOM data.')
-    parser.add_option('-i', '--dcmdir', action='store',
-                      dest='dcmdir', default=None,
-                      help=help['dcm_dir'])
-    parser.add_option('-o', '--outputfile', action='store',
-                      dest='out_filename', default='output.mat',
-                      help=help['out_file'])
-    parser.add_option('--degrad', action='store',
-                      dest='degrad', default=1,
-                      help=help['degrad'])
-    parser.add_option('-z', '--zoom', action='store',
-                      dest='zoom', default='1',
-                      help=help['zoom'])
-    parser.add_option('-d', '--debug', action='store_true',
-                      dest='debug',
-                      help=help['debug'])
+    parser = OptionParser(description="Read DIOCOM data.")
+    parser.add_option(
+        "-i",
+        "--dcmdir",
+        action="store",
+        dest="dcmdir",
+        default=None,
+        help=help["dcm_dir"],
+    )
+    parser.add_option(
+        "-o",
+        "--outputfile",
+        action="store",
+        dest="out_filename",
+        default="output.mat",
+        help=help["out_file"],
+    )
+    parser.add_option(
+        "--degrad", action="store", dest="degrad", default=1, help=help["degrad"]
+    )
+    parser.add_option(
+        "-z", "--zoom", action="store", dest="zoom", default="1", help=help["zoom"]
+    )
+    parser.add_option(
+        "-d", "--debug", action="store_true", dest="debug", help=help["debug"]
+    )
     (options, args) = parser.parse_args()
 
-    logger.setLevel(logging.WARNING)
-    ch = logging.StreamHandler()
-    logger.addHandler(ch)
+    # logger.setLevel(logging.WARNING)
+    # ch = logging.StreamHandler()
+    # logger.addHandler(ch)
 
     if options.debug:
-        logger.setLevel(logging.DEBUG)
+        logger.add(level="debug")
+        # logger.setLevel(logging.DEBUG)
 
     if options.dcmdir is None:
         dcmdir = get_dcmdir_qt()
         if dcmdir is None:
-            raise IOError('No DICOM directory!')
+            raise IOError("No DICOM directory!")
     else:
         dcmdir = options.dcmdir
 
@@ -1119,17 +1201,13 @@ if __name__ == "__main__":  # pragma: no cover
         # oom = float(options.zoom)
         # mport pdb; pdb.set_trace()
         data3d = scipy.ndimage.zoom(data3d, zoom=zoom)
-        metadata['voxelsize_mm'] = list(np.array(metadata['voxelsize_mm']) /
-                                        zoom)
+        metadata["voxelsize_mm"] = list(np.array(metadata["voxelsize_mm"]) / zoom)
 
     degrad = int(options.degrad)
 
     data3d_out = data3d[::degrad, ::degrad, ::degrad]
-    vs_out = list(np.array(metadata['voxelsize_mm']) * degrad)
+    vs_out = list(np.array(metadata["voxelsize_mm"]) * degrad)
 
-    logger.debug('voxelsize_mm ' + vs_out.__str__())
-    savemat(options.out_filename,
-            {'data': data3d_out, 'voxelsize_mm': vs_out}
-            )
+    logger.debug("voxelsize_mm " + vs_out.__str__())
+    savemat(options.out_filename, {"data": data3d_out, "voxelsize_mm": vs_out})
     print("Data size: %d, shape: %s" % (data3d_out.nbytes, data3d_out.shape))
-
