@@ -4,8 +4,7 @@
 # import sys
 import os
 
-import logging
-logger = logging.getLogger(__name__)
+from loguru import logger
 
 import sys
 import os.path
@@ -17,19 +16,20 @@ path_to_script = os.path.dirname(os.path.abspath(__file__))
 
 
 def get_tar_output_dir(fname):
-    if (fname.endswith("tar.bz2")):
+    if fname.endswith("tar.bz2"):
         fname = fname[:-8]
         return fname
 
+
 def untar(fname, path=".", output_dir_by_filename=True, force_rewrite=False):
     if output_dir_by_filename:
-        path= get_tar_output_dir(fname)
+        path = get_tar_output_dir(fname)
     if os.path.exists(path) and force_rewrite is False:
         logger.debug("Extraction of tar file interrupted. Directory %s exists" % path)
         return path
 
     # extraction
-    if (fname.endswith("tar.bz2")):
+    if fname.endswith("tar.bz2"):
         if path != ".":
             os.makedirs(path)
         tar = tarfile.open(fname)
@@ -40,5 +40,3 @@ def untar(fname, path=".", output_dir_by_filename=True, force_rewrite=False):
         return path
     else:
         logger.warning("Not a tar.bz2 file: '%s '" % path)
-
-
